package es.unican.docencia.y2012.ed.delegados;

/**
 * Clase que representa un cuadrado con un crculo inscrito 
 * en l. Los lados del crculo son tangentes al crculo.
 * @author Pablo Sanchez (p.sanchez@unican.es)
 * http://personales.unican.es/sanchezbp 
 * 
 */
public class CuadradoCirculoInscrito {
	
	// El circulo inscrito en el cuadrado
	protected ICirculo  circ = null; // Inv: circ != null
	// El cuadrado en s
	protected ICuadrado cuad = null; // Inv: circ != null
	// Inv: circ.getX() == cuad.getX();
	// Inv: circ.getY() == cuad.getY();
	// Inv: circ.getRadio() == cuad.getLado() div 2;  
	
	/**
	 * Construye un cuadrado con un circulo inscrito a partir
	 * del radio del crculo y las coordenadas del centro del 
	 * cuadrado, que es tambien el centro del circulo
	 * @param x La abscisa de las coordenadas del centro
	 * @param y La ordenada de las coordenadas del centro
	 * @param radio 
	 */
	public CuadradoCirculoInscrito(int x, int y, int radio) {
		this.circ = new Circulo(x,y,radio);
		this.cuad = new Cuadrado(x,y,2*radio);
	} // CuadradoCirculoInscrito

	/**
	 * @see es.unican.docencia.y2012.ed.delegados.ICirculo#getRadio()
	 */
	public int getRadio() {
		return circ.getRadio();
	} // getRadio 

	/**
	 * @see es.unican.docencia.y2012.ed.delegados.ICirculo#setRadio(int)
	 */
	public void setRadio(int radio) {
		circ.setRadio(radio);
		cuad.setLado(radio*2);
	} // setRadio

	/**
	 * @see es.unican.docencia.y2012.ed.delegados.ICirculo#getX()
	 */
	public int getX() {
		return circ.getX();
	} // getX

	/**
	 * @see es.unican.docencia.y2012.ed.delegados.ICirculo#setX(int)
	 */
	public void setX(int x) {
		circ.setX(x);
		cuad.setX(x);
	} // setX

	/**
	 * @see es.unican.docencia.y2012.ed.delegados.ICirculo#getY()
	 */
	public int getY() {
		return circ.getY();
	} // getY

	/**
	 * @see es.unican.docencia.y2012.ed.delegados.ICirculo#setY(int)
	 */
	public void setY(int y) {
		circ.setY(y);
		cuad.setY(y);
	} // setY

	/**
	 * @see es.unican.docencia.y2012.ed.delegados.ICuadrado#getLado()
	 */
	public int getLado() {
		return cuad.getLado();
	} // getLado

	/**
	 * @see es.unican.docencia.y2012.ed.delegados.ICuadrado#setLado(int)
	 */
	public void setLado(int lado) {
		cuad.setLado(lado);
		circ.setRadio((int) lado/2);
	} // setLado
		
} // CuadradoCirculoInscrito
